from deepranker import add, divide, multiply, subtract


def test_add() -> None:
    assert add(10, 5) == 15


def test_subtract() -> None:
    assert subtract(10, 5) == 5


def test_multiply() -> None:
    assert multiply(10, 5) == 50


def test_divide() -> None:
    assert divide(10, 5) == 2


def test_divide_by_zero_raises_value_error() -> None:
    try:
        divide(10, 0)
    except ValueError as exc:
        assert str(exc) == "Bir sayı sıfıra bölünemez."
    else:
        raise AssertionError("ValueError was not raised")
