from src.FeatureRank.basic_operator import add, subtract, multiply, divide

print("Toplama:", add(10, 5))
print("Çıkarma:", subtract(10, 5))
print("Çarpma:", multiply(10, 5))
print("Bölme:", divide(10, 5))